@@ -20,13 +20,13 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.00_02';
+our $VERSION = '0.00_03';
 
 use parent 'Template::Plugin';
 use Lingua::EN::Inflexion 0.001008 'inflect';
 
 sub new {
-    my ($class, $context) = @_;
+	my ($class, $context) = @_;
 
 	my $filter_factory = sub {
 		shift;
@@ -67,17 +67,31 @@ Template::Plugin::Lingua::EN::Inflexion - Interface to Lingua::EN::Inflexion mod
 
 =head1 SYNOPSIS
 
+  use strict;
+  use warnings;
+  use Template;
+  
+  my $tsrc = <<'EOT';
   [% USE infl = Lingua.EN.Inflexion; -%]
-  [% n = 42; FILTER inflect; -%]
-    <#d:$n>There <V:was> <#n:$n> <N:error>.
-    <A:This> <N:error> <V:was> fatal.
-    ... and <#o:9>ly...
+  [% FOR obj IN objects; -%]
+  [% FOR n IN [0, 1, 2]; -%]
+  [% FILTER inflect; -%]
+    <#d:$n>There <V:was> <#n:$n> <N:$obj.name>.
+  [% IF n > 0 %]  <A:This> <N:$obj.name> <V:was> ${obj.colour}.
+  [% END; END; END %]
   [% END; -%]
-
-  # Output:
-  #   There were 42 errors.
-  #   These errors were fatal.
-  #   ... and 9thly...
+  EOT
+  
+  my $data = {
+    objects => [
+        { name => 'dog', colour => 'brown' },
+        { name => 'goose', colour => 'white' },
+        { name => 'fish', colour => 'gold' }
+    ]
+  };
+  
+  my $template = Template->new ({INTERPOLATE => 1});
+  $template->process (\$tsrc, $data);
 
 =head1 DESCRIPTION
 
@@ -94,7 +108,7 @@ L<Lingua::EN::Inflexion> manual.
 
 =head2 new
 
-	my $infl = Template::Plugin::Lingua::EN::Inflexion->new ($context);
+    my $infl = Template::Plugin::Lingua::EN::Inflexion->new ($context);
 
 The constructor takes one argument which is the context on which the
 filter will be defined and returns the new object. You will not need to
@@ -174,7 +188,7 @@ Other works are
 
 =over
 
-Copyright © 2019 Pete Houston
+Copyright © 2019-2020 Pete Houston
 
 =back
 
